import fire


class TochCli(object):

    def configure(self):
        apikey = input("Enter api key:: ")
        #self.__test()
        print ("Api key saved")

    
    
    def __test(self):
        print ("test")
    

def main():
    
    fire.Fire(TochCli)


if __name__ == "__main__":
    print("Wellcome to tochCLI version 0.1.0")
    main()
    





import click


class TochCli(object):

    
    def __test(self):
        print ("test")
    
@click.command()
def configure():
    apikey = input("Enter api key:: ")
    print ("Api key saved")



def main():
    #configure()
    pass


if __name__ == "__main__":
    print("Wellcome to tochCLI version 0.1.0")
    
    main()
    





"""tochsdk setup.py
"""
from setuptools import setup, find_packages

setup(
    name="tochsdk",
    version="0.1.0",
    description="Toch ai commond line interface",
    packages=find_packages(),
    install_requires=[
        "fire"
    ],
    entry_points={
        'console_scripts': ['tochcli=tochsdk.tochsdk:main']
    },
    author="toch team",
    license="MIT"
)
